@@ -19,13 +19,9 @@ import os.path as osp
 import sys
 import gettext
 
-from guidata.qt.QtGui import (QFont, QLabel, QPixmap, QIcon, QHBoxLayout,
-                              QColor, QPen, QBrush, QFontDatabase)
-from guidata.qt.QtCore import Qt
-
 from guidata.utils import get_module_path, decode_fs_string
 
-from guidata.py3compat import is_unicode, to_text_string, PY3, is_text_string
+from qtpy.py3compat import is_unicode, to_text_string, PY3, is_text_string
 
 IMG_PATH = []
 
@@ -33,33 +29,36 @@ IMG_PATH = []
 def get_module_data_path(modname, relpath=None):
     """Return module *modname* data path
     Handles py2exe/cx_Freeze distributions"""
-    datapath = getattr(sys.modules[modname], 'DATAPATH', '')
+    datapath = getattr(sys.modules[modname], "DATAPATH", "")
     if not datapath:
         datapath = get_module_path(modname)
         parentdir = osp.normpath(osp.join(datapath, osp.pardir))
         if osp.isfile(parentdir):
             # Parent directory is not a directory but the 'library.zip' file:
             # this is either a py2exe or a cx_Freeze distribution
-            datapath = osp.abspath(osp.join(osp.join(parentdir, osp.pardir),
-                                            modname))
+            datapath = osp.abspath(osp.join(osp.join(parentdir, osp.pardir), modname))
     if relpath is not None:
         datapath = osp.abspath(osp.join(datapath, relpath))
     return datapath
 
+
 def get_translation(modname, dirname=None):
     """Return translation callback for module *modname*"""
     if dirname is None:
         dirname = modname
     # fixup environment var LANG in case it's unknown
     if "LANG" not in os.environ:
-        import locale # Warning: 2to3 false alarm ('import' fixer)
+        import locale  # Warning: 2to3 false alarm ('import' fixer)
+
         lang = locale.getdefaultlocale()[0]
         if lang is not None:
             os.environ["LANG"] = lang
     try:
-        _trans = gettext.translation(modname, get_module_locale_path(dirname),
-                                     codeset="utf-8")
+        _trans = gettext.translation(
+            modname, get_module_locale_path(dirname), codeset="utf-8"
+        )
         lgettext = _trans.lgettext
+
         def translate_gettext(x):
             if not PY3 and is_unicode(x):
                 x = x.encode("utf-8")
@@ -68,22 +67,26 @@ def get_translation(modname, dirname=None):
                 return y
             else:
                 return to_text_string(y, "utf-8")
+
         return translate_gettext
     except IOError as _e:
-        #print "Not using translations (%s)" % _e
+        # print "Not using translations (%s)" % _e
         def translate_dumb(x):
             if not is_unicode(x):
                 return to_text_string(x, "utf-8")
             return x
+
         return translate_dumb
 
+
 def get_module_locale_path(modname):
     """Return module *modname* gettext translation path"""
-    localepath = getattr(sys.modules[modname], 'LOCALEPATH', '')
+    localepath = getattr(sys.modules[modname], "LOCALEPATH", "")
     if not localepath:
         localepath = get_module_data_path(modname, relpath="locale")
     return localepath
 
+
 def add_image_path(path, subfolders=True):
     """Append image path (opt. with its subfolders) to global list IMG_PATH"""
     if not is_unicode(path):
@@ -96,6 +99,7 @@ def add_image_path(path, subfolders=True):
             if osp.isdir(pth):
                 IMG_PATH.append(pth)
 
+
 def add_image_module_path(modname, relpath, subfolders=True):
     """
     Appends image data path relative to a module name.
@@ -107,6 +111,7 @@ def add_image_module_path(modname, relpath, subfolders=True):
     """
     add_image_path(get_module_data_path(modname, relpath=relpath), subfolders)
 
+
 def get_image_file_path(name, default="not_found.png"):
     """
     Return the absolute path to image with specified name
@@ -122,7 +127,7 @@ def get_image_file_path(name, default="not_found.png"):
         except RuntimeError:
             raise RuntimeError("Image file %r not found" % name)
     else:
-        raise RuntimeError() 
+        raise RuntimeError()
 
 
 def get_icon(name, default="not_found.png"):
@@ -130,7 +135,9 @@ def get_icon(name, default="not_found.png"):
     Construct a QIcon from the file with specified name
     name, default: filenames with extensions
     """
-    return QIcon(get_image_file_path(name, default))
+    from qtpy import QtGui as QG
+
+    return QG.QIcon(get_image_file_path(name, default))
 
 
 def get_image_label(name, default="not_found.png"):
@@ -138,44 +145,62 @@ def get_image_label(name, default="not_found.png"):
     Construct a QLabel from the file with specified name
     name, default: filenames with extensions
     """
-    label = QLabel()
-    pixmap = QPixmap(get_image_file_path(name, default))
+    from qtpy import QtGui as QG
+    from qtpy import QtWidgets as QW
+
+    label = QW.QLabel()
+    pixmap = QG.QPixmap(get_image_file_path(name, default))
     label.setPixmap(pixmap)
     return label
 
 
-def get_image_layout(imagename, text="", tooltip="", alignment=Qt.AlignLeft):
+def get_image_layout(imagename, text="", tooltip="", alignment=None):
     """
     Construct a QHBoxLayout including image from the file with specified name,
     left-aligned text [with specified tooltip]
     Return (layout, label)
     """
-    layout = QHBoxLayout()
-    if alignment in (Qt.AlignCenter, Qt.AlignRight):
+    from qtpy import QtWidgets as QW
+    from qtpy import QtCore as QC
+
+    if alignment is None:
+        alignment = QC.Qt.AlignLeft
+    layout = QW.QHBoxLayout()
+    if alignment in (QC.Qt.AlignCenter, QC.Qt.AlignRight):
         layout.addStretch()
     layout.addWidget(get_image_label(imagename))
-    label = QLabel(text)
+    label = QW.QLabel(text)
     label.setToolTip(tooltip)
     layout.addWidget(label)
-    if alignment in (Qt.AlignCenter, Qt.AlignLeft):
+    if alignment in (QC.Qt.AlignCenter, QC.Qt.AlignLeft):
         layout.addStretch()
-    return (layout, label)    
+    return (layout, label)
 
 
 def font_is_installed(font):
     """Check if font is installed"""
-    return [fam for fam in QFontDatabase().families()
-            if to_text_string(fam)==font]
+    from qtpy import QtGui as QG
+
+    return [fam for fam in QG.QFontDatabase().families() if to_text_string(fam) == font]
 
 
-MONOSPACE = ['Courier New', 'Bitstream Vera Sans Mono', 'Andale Mono',
-             'Liberation Mono', 'Monaco', 'Courier', 'monospace', 'Fixed',
-             'Terminal']
+MONOSPACE = [
+    "Courier New",
+    "Bitstream Vera Sans Mono",
+    "Andale Mono",
+    "Liberation Mono",
+    "Monaco",
+    "Courier",
+    "monospace",
+    "Fixed",
+    "Terminal",
+]
+
 
 def get_family(families):
     """Return the first installed font family in family list"""
     if not isinstance(families, list):
-        families = [ families ]
+        families = [families]
     for family in families:
         if font_is_installed(family):
             return family
@@ -190,36 +215,37 @@ def get_font(conf, section, option=""):
     conf: UserConfig instance
     section [, option]: configuration entry
     """
+    from qtpy import QtGui as QG
+
     if not option:
         option = "font"
-    if 'font' not in option:
-        option += '/font'
-    font = QFont()
-    if conf.has_option(section, option+'/family/nt'):
-        families = conf.get(section, option+'/family/'+os.name)
-    elif conf.has_option(section, option+'/family'):
-        families = conf.get(section, option+'/family')
+    if "font" not in option:
+        option += "/font"
+    font = QG.QFont()
+    if conf.has_option(section, option + "/family/nt"):
+        families = conf.get(section, option + "/family/" + os.name)
+    elif conf.has_option(section, option + "/family"):
+        families = conf.get(section, option + "/family")
     else:
         families = None
     if families is not None:
         if not isinstance(families, list):
-            families = [ families ]
+            families = [families]
         family = None
         for family in families:
             if font_is_installed(family):
                 break
         font.setFamily(family)
-    if conf.has_option(section, option+'/size'):
-        font.setPointSize(conf.get(section, option+'/size'))
-    if conf.get(section, option+'/bold', False):
-        font.setWeight(QFont.Bold)
+    if conf.has_option(section, option + "/size"):
+        font.setPointSize(conf.get(section, option + "/size"))
+    if conf.get(section, option + "/bold", False):
+        font.setWeight(QG.QFont.Bold)
     else:
-        font.setWeight(QFont.Normal)
+        font.setWeight(QG.QFont.Normal)
     return font
-    
-    
-def get_pen(conf, section, option="",
-            color="black", width=1, style='SolidLine'):
+
+
+def get_pen(conf, section, option="", color="black", width=1, style="SolidLine"):
     """
     Construct a QPen from the specified configuration file entry
     conf: UserConfig instance
@@ -228,14 +254,17 @@ def get_pen(conf, section, option="",
     [width]: default width
     [style]: default style
     """
-    if 'pen' not in option:
-        option += '/pen'
-    color = conf.get(section, option+"/color", color)
-    color = QColor(color)
-    width = conf.get(section, option+"/width", width)
-    style_name = conf.get(section, option+"/style", style)
-    style = getattr(Qt, style_name)
-    return QPen(color, width, style)
+    from qtpy import QtGui as QG
+    from qtpy import QtCore as QC
+
+    if "pen" not in option:
+        option += "/pen"
+    color = conf.get(section, option + "/color", color)
+    color = QG.QColor(color)
+    width = conf.get(section, option + "/width", width)
+    style_name = conf.get(section, option + "/style", style)
+    style = getattr(QC.Qt, style_name)
+    return QG.QPen(color, width, style)
 
 
 def get_brush(conf, section, option="", color="black", alpha=1.0):
@@ -246,11 +275,13 @@ def get_brush(conf, section, option="", color="black", alpha=1.0):
     [color]: default color
     [alpha]: default alpha-channel
     """
-    if 'brush' not in option:
-        option += '/brush'
-    color = conf.get(section, option+"/color", color)
-    color = QColor(color)
-    alpha = conf.get(section, option+"/alphaF", alpha)
+    from qtpy import QtGui as QG
+
+    if "brush" not in option:
+        option += "/brush"
+    color = conf.get(section, option + "/color", color)
+    color = QG.QColor(color)
+    alpha = conf.get(section, option + "/alphaF", alpha)
     color.setAlphaF(alpha)
-    return QBrush(color)
+    return QG.QBrush(color)
 
