@@ -31,27 +31,39 @@ try:
 except ImportError:
     pass
 
-from guidata.qt.QtGui import (QDialog, QMessageBox, QDialogButtonBox, QWidget,
-                              QVBoxLayout, QGridLayout, QLabel, QSpacerItem,
-                              QColor, QTabWidget, QIcon, QApplication, QPainter,
-                              QPicture, QBrush, QGroupBox, QPushButton)
-from guidata.qt.QtCore import Qt, QRect, QSize, Signal
-from guidata.qt.compat import getopenfilename, getopenfilenames, getsavefilename
+from qtpy.QtWidgets import (
+    QDialog,
+    QMessageBox,
+    QDialogButtonBox,
+    QWidget,
+    QVBoxLayout,
+    QGridLayout,
+    QLabel,
+    QSpacerItem,
+    QTabWidget,
+    QApplication,
+    QGroupBox,
+    QPushButton,
+)
+from qtpy.QtGui import QColor, QIcon, QPainter, QPicture, QBrush
+from qtpy.QtCore import Qt, QRect, QSize, Signal
+from qtpy.compat import getopenfilename, getopenfilenames, getsavefilename
 
 from guidata.configtools import get_icon
 from guidata.config import _
-from guidata.py3compat import to_text_string, is_text_string
+from qtpy.py3compat import to_text_string, is_text_string
 
-from guidata.dataset.datatypes import (BeginGroup, EndGroup, GroupItem,
-                                       TabGroupItem)
+from guidata.dataset.datatypes import BeginGroup, EndGroup, GroupItem, TabGroupItem
 
 
 class DataSetEditDialog(QDialog):
     """
     Dialog box for DataSet editing
     """
-    def __init__(self, instance, icon='', parent=None, apply=None,
-                 wordwrap=True, size=None):
+
+    def __init__(
+        self, instance, icon="", parent=None, apply=None, wordwrap=True, size=None
+    ):
         QDialog.__init__(self, parent)
         self.wordwrap = wordwrap
         self.apply_func = apply
@@ -61,32 +73,33 @@ class DataSetEditDialog(QDialog):
             label.setWordWrap(wordwrap)
             self.layout.addWidget(label)
         self.instance = instance
-        self.edit_layout = [  ]
+        self.edit_layout = []
 
-        self.setup_instance( instance )
+        self.setup_instance(instance)
 
         if apply is not None:
             apply_button = QDialogButtonBox.Apply
         else:
             apply_button = QDialogButtonBox.NoButton
-        bbox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel
-                                | apply_button )
+        bbox = QDialogButtonBox(
+            QDialogButtonBox.Ok | QDialogButtonBox.Cancel | apply_button
+        )
         self.bbox = bbox
         bbox.accepted.connect(self.accept)
         bbox.rejected.connect(self.reject)
         bbox.clicked.connect(self.button_clicked)
         self.layout.addWidget(bbox)
-        
+
         self.setLayout(self.layout)
-        
+
         if parent is None:
             if not isinstance(icon, QIcon):
                 icon = get_icon(icon, default="guidata.svg")
             self.setWindowIcon(icon)
-        
+
         self.setModal(True)
         self.setWindowTitle(instance.get_title())
-        
+
         if size is not None:
             if isinstance(size, QSize):
                 self.resize(size)
@@ -95,32 +108,32 @@ class DataSetEditDialog(QDialog):
 
     def button_clicked(self, button):
         role = self.bbox.buttonRole(button)
-        if role==QDialogButtonBox.ApplyRole and self.apply_func is not None:
+        if role == QDialogButtonBox.ApplyRole and self.apply_func is not None:
             if self.check():
                 for edl in self.edit_layout:
                     edl.accept_changes()
                 self.apply_func(self.instance)
-    
+
     def setup_instance(self, instance):
         """Construct main layout"""
         grid = QGridLayout()
         grid.setAlignment(Qt.AlignTop)
         self.layout.addLayout(grid)
-        self.edit_layout.append( self.layout_factory( instance, grid) )
-        
-    def layout_factory(self, instance, grid ):
+        self.edit_layout.append(self.layout_factory(instance, grid))
+
+    def layout_factory(self, instance, grid):
         """A factory method that produces instances of DataSetEditLayout
         
         or derived classes (see DataSetShowDialog)
         """
-        return DataSetEditLayout( self, instance, grid )
+        return DataSetEditLayout(self, instance, grid)
 
     def child_title(self, item):
         """Return data item title combined with QApplication title"""
         app_name = QApplication.applicationName()
         if not app_name:
             app_name = self.instance.get_title()
-        return "%s - %s" % ( app_name, item.label() )
+        return "%s - %s" % (app_name, item.label())
 
     def check(self):
         is_ok = True
@@ -128,9 +141,13 @@ class DataSetEditDialog(QDialog):
             if not edl.check_all_values():
                 is_ok = False
         if not is_ok:
-            QMessageBox.warning(self, self.instance.get_title(),
-                        _("Some required entries are incorrect")+"\n"+\
-                        _("Please check highlighted fields."))
+            QMessageBox.warning(
+                self,
+                self.instance.get_title(),
+                _("Some required entries are incorrect")
+                + "\n"
+                + _("Please check highlighted fields."),
+            )
             return False
         return True
 
@@ -146,12 +163,14 @@ class DataSetGroupEditDialog(DataSetEditDialog):
     """
     Tabbed dialog box for DataSet editing
     """
+
     def setup_instance(self, instance):
         """Override DataSetEditDialog method"""
         from guidata.dataset.datatypes import DataSetGroup
+
         assert isinstance(instance, DataSetGroup)
         tabs = QTabWidget()
-#        tabs.setUsesScrollButtons(False)
+        #        tabs.setUsesScrollButtons(False)
         self.layout.addWidget(tabs)
         for dataset in instance.datasets:
             layout = QVBoxLayout()
@@ -161,22 +180,21 @@ class DataSetGroupEditDialog(DataSetEditDialog):
                 label.setWordWrap(self.wordwrap)
                 layout.addWidget(label)
             grid = QGridLayout()
-            self.edit_layout.append( self.layout_factory(dataset, grid) )
+            self.edit_layout.append(self.layout_factory(dataset, grid))
             layout.addLayout(grid)
             page = QWidget()
             page.setLayout(layout)
             if dataset.get_icon():
-                tabs.addTab( page, get_icon(dataset.get_icon()),
-                             dataset.get_title() )
+                tabs.addTab(page, get_icon(dataset.get_icon()), dataset.get_title())
             else:
-                tabs.addTab( page, dataset.get_title() )
-
+                tabs.addTab(page, dataset.get_title())
 
 
 class DataSetEditLayout(object):
     """
     Layout in which data item widgets are placed
     """
+
     _widget_factory = {}
 
     @classmethod
@@ -190,29 +208,29 @@ class DataSetEditLayout(object):
         self.layout = layout
         self.first_line = first_line
         self.widgets = []
-        self.linenos = {} # prochaine ligne à remplir par colonne
+        self.linenos = {}  # prochaine ligne à remplir par colonne
         self.items_pos = {}
         if not items:
             items = self.instance._items
-        items = self.transform_items( items )
-        self.setup_layout( items )
+        items = self.transform_items(items)
+        self.setup_layout(items)
 
     def transform_items(self, items):
         """
         Handle group of items: transform items into a GroupItem instance
         if they are located between BeginGroup and EndGroup
         """
-        item_lists = [ [] ]
+        item_lists = [[]]
         for item in items:
             if isinstance(item, BeginGroup):
                 item = item.get_group()
                 item_lists[-1].append(item)
-                item_lists.append( item.group )
+                item_lists.append(item.group)
             elif isinstance(item, EndGroup):
                 item_lists.pop()
             else:
                 item_lists[-1].append(item)
-        assert len(item_lists)==1
+        assert len(item_lists) == 1
         return item_lists[-1]
 
     def check_all_values(self):
@@ -221,25 +239,32 @@ class DataSetEditLayout(object):
             if widget.is_active() and not widget.check():
                 return False
         return True
-    
+
     def accept_changes(self):
         """Accept changes made to widget inputs"""
         self.update_dataitems()
 
     def setup_layout(self, items):
         """Place items on layout"""
+
         def last_col(col, span):
             """Return last column (which depends on column span)"""
             if not span:
                 return col
             else:
-                return col+span-1
-        colmax = max( [ last_col(item.get_prop("display", "col"),
-                                 item.get_prop("display", "colspan"))
-                        for item in items ] )
+                return col + span - 1
+
+        colmax = max(
+            [
+                last_col(
+                    item.get_prop("display", "col"), item.get_prop("display", "colspan")
+                )
+                for item in items
+            ]
+        )
         self.items_pos = {}
         line = self.first_line - 1
-        last_item = [-1, 0, colmax ]
+        last_item = [-1, 0, colmax]
         for item in items:
             beg = item.get_prop("display", "col")
             span = item.get_prop("display", "colspan")
@@ -250,7 +275,7 @@ class DataSetEditLayout(object):
                 #  est avant la colonne de debut de l'item précédent
                 line += 1
             else:
-                last_item[2] = beg-last_item[1]
+                last_item[2] = beg - last_item[1]
             last_item = [line, beg, span]
             self.items_pos[item] = last_item
 
@@ -259,14 +284,14 @@ class DataSetEditLayout(object):
             if hide:
                 continue
             widget = self.build_widget(item)
-            self.add_row( widget )
+            self.add_row(widget)
 
         self.refresh_widgets()
 
     def build_widget(self, item):
         factory = self._widget_factory[type(item)]
-        widget = factory( item.bind(self.instance), self )
-        self.widgets.append( widget )
+        widget = factory(item.bind(self.instance), self)
+        self.widgets.append(widget)
         return widget
 
     def add_row(self, widget):
@@ -274,9 +299,9 @@ class DataSetEditLayout(object):
         item = widget.item
         line, col, span = self.items_pos[item.item]
         if col > 0:
-            self.layout.addItem( QSpacerItem(20, 1), line, col*3-1 )
-            
-        widget.place_on_grid( self.layout, line, col*3, col*3 + 1, 1, 3*span-2)
+            self.layout.addItem(QSpacerItem(20, 1), line, col * 3 - 1)
+
+        widget.place_on_grid(self.layout, line, col * 3, col * 3 + 1, 1, 3 * span - 2)
         try:
             widget.get()
         except Exception:
@@ -299,20 +324,48 @@ class DataSetEditLayout(object):
         for widget in self.widgets:
             if widget is not except_this_one:
                 widget.get()
-        
 
 
 # Enregistrement des correspondances avec les widgets
-from guidata.dataset.qtitemwidgets import (LineEditWidget, TextEditWidget,
-                CheckBoxWidget, ColorWidget, FileWidget, DirectoryWidget,
-                ChoiceWidget, MultipleChoiceWidget, FloatArrayWidget,
-                GroupWidget, AbstractDataSetWidget, ButtonWidget,
-                TabGroupWidget, DateWidget, DateTimeWidget, SliderWidget,
-                FloatSliderWidget)
-from guidata.dataset.dataitems import (FloatItem, StringItem, TextItem, IntItem,
-                BoolItem, ColorItem, FileOpenItem, FilesOpenItem, FileSaveItem,
-                DirectoryItem, ChoiceItem, ImageChoiceItem, MultipleChoiceItem,
-                FloatArrayItem, ButtonItem, DateItem, DateTimeItem, DictItem)
+from guidata.dataset.qtitemwidgets import (
+    LineEditWidget,
+    TextEditWidget,
+    CheckBoxWidget,
+    ColorWidget,
+    FileWidget,
+    DirectoryWidget,
+    ChoiceWidget,
+    MultipleChoiceWidget,
+    FloatArrayWidget,
+    GroupWidget,
+    AbstractDataSetWidget,
+    ButtonWidget,
+    TabGroupWidget,
+    DateWidget,
+    DateTimeWidget,
+    SliderWidget,
+    FloatSliderWidget,
+)
+from guidata.dataset.dataitems import (
+    FloatItem,
+    StringItem,
+    TextItem,
+    IntItem,
+    BoolItem,
+    ColorItem,
+    FileOpenItem,
+    FilesOpenItem,
+    FileSaveItem,
+    DirectoryItem,
+    ChoiceItem,
+    ImageChoiceItem,
+    MultipleChoiceItem,
+    FloatArrayItem,
+    ButtonItem,
+    DateItem,
+    DateTimeItem,
+    DictItem,
+)
 
 DataSetEditLayout.register(GroupItem, GroupWidget)
 DataSetEditLayout.register(TabGroupItem, TabGroupWidget)
@@ -325,12 +378,15 @@ DataSetEditLayout.register(BoolItem, CheckBoxWidget)
 DataSetEditLayout.register(DateItem, DateWidget)
 DataSetEditLayout.register(DateTimeItem, DateTimeWidget)
 DataSetEditLayout.register(ColorItem, ColorWidget)
-DataSetEditLayout.register(FileOpenItem, lambda item,
-                           parent: FileWidget(item, parent, getopenfilename) )
-DataSetEditLayout.register(FilesOpenItem, lambda item,
-                           parent: FileWidget(item, parent, getopenfilenames) )
-DataSetEditLayout.register(FileSaveItem, lambda item,
-                           parent: FileWidget(item, parent, getsavefilename) )
+DataSetEditLayout.register(
+    FileOpenItem, lambda item, parent: FileWidget(item, parent, getopenfilename)
+)
+DataSetEditLayout.register(
+    FilesOpenItem, lambda item, parent: FileWidget(item, parent, getopenfilenames)
+)
+DataSetEditLayout.register(
+    FileSaveItem, lambda item, parent: FileWidget(item, parent, getsavefilename)
+)
 DataSetEditLayout.register(DirectoryItem, DirectoryWidget)
 DataSetEditLayout.register(ChoiceItem, ChoiceWidget)
 DataSetEditLayout.register(ImageChoiceItem, ChoiceWidget)
@@ -345,18 +401,21 @@ QLabel { font-weight: bold; color: blue }
 QLabel:disabled { font-weight: bold; color: grey }
 """
 
+
 class DataSetShowWidget(AbstractDataSetWidget):
     """Read-only base widget"""
+
     READ_ONLY = True
+
     def __init__(self, item, parent_layout):
         AbstractDataSetWidget.__init__(self, item, parent_layout)
         self.group = QLabel()
         wordwrap = item.get_prop_value("display", "wordwrap", False)
         self.group.setWordWrap(wordwrap)
         self.group.setToolTip(item.get_help())
-        self.group.setStyleSheet( LABEL_CSS )
+        self.group.setStyleSheet(LABEL_CSS)
         self.group.setTextInteractionFlags(Qt.TextSelectableByMouse)
-        #self.group.setEnabled(False)
+        # self.group.setEnabled(False)
 
     def get(self):
         """Override AbstractDataSetWidget method"""
@@ -368,12 +427,14 @@ class DataSetShowWidget(AbstractDataSetWidget):
         """Read only..."""
         pass
 
+
 class ShowColorWidget(DataSetShowWidget):
     """Read-only color item widget"""
+
     def __init__(self, item, parent_layout):
         DataSetShowWidget.__init__(self, item, parent_layout)
         self.picture = None
-        
+
     def get(self):
         """Override AbstractDataSetWidget method"""
         value = self.item.get()
@@ -386,10 +447,13 @@ class ShowColorWidget(DataSetShowWidget):
             painter.end()
             self.group.setPicture(self.picture)
 
+
 class ShowBooleanWidget(DataSetShowWidget):
     """Read-only bool item widget"""
-    def place_on_grid(self, layout, row, label_column, widget_column,
-                      row_span=1, column_span=1):
+
+    def place_on_grid(
+        self, layout, row, label_column, widget_column, row_span=1, column_span=1
+    ):
         """Override AbstractDataSetWidget method"""
         if not self.item.get_prop_value("display", "label"):
             widget_column = label_column
@@ -397,7 +461,7 @@ class ShowBooleanWidget(DataSetShowWidget):
         else:
             self.place_label(layout, row, label_column)
         layout.addWidget(self.group, row, widget_column, row_span, column_span)
-        
+
     def get(self):
         """Override AbstractDataSetWidget method"""
         DataSetShowWidget.get(self)
@@ -413,13 +477,17 @@ class ShowBooleanWidget(DataSetShowWidget):
 
 class DataSetShowLayout(DataSetEditLayout):
     """Read-only layout"""
+
     _widget_factory = {}
 
+
 class DataSetShowDialog(DataSetEditDialog):
     """Read-only dialog box"""
-    def layout_factory(self, instance, grid ):
+
+    def layout_factory(self, instance, grid):
         """Override DataSetEditDialog method"""
-        return DataSetShowLayout( self, instance, grid )
+        return DataSetShowLayout(self, instance, grid)
+
 
 DataSetShowLayout.register(GroupItem, GroupWidget)
 DataSetShowLayout.register(TabGroupItem, TabGroupWidget)
@@ -431,9 +499,9 @@ DataSetShowLayout.register(BoolItem, ShowBooleanWidget)
 DataSetShowLayout.register(DateItem, DataSetShowWidget)
 DataSetShowLayout.register(DateTimeItem, DataSetShowWidget)
 DataSetShowLayout.register(ColorItem, ShowColorWidget)
-DataSetShowLayout.register(FileOpenItem, DataSetShowWidget )
-DataSetShowLayout.register(FilesOpenItem, DataSetShowWidget )
-DataSetShowLayout.register(FileSaveItem, DataSetShowWidget )
+DataSetShowLayout.register(FileOpenItem, DataSetShowWidget)
+DataSetShowLayout.register(FilesOpenItem, DataSetShowWidget)
+DataSetShowLayout.register(FileSaveItem, DataSetShowWidget)
 DataSetShowLayout.register(DirectoryItem, DataSetShowWidget)
 DataSetShowLayout.register(ChoiceItem, DataSetShowWidget)
 DataSetShowLayout.register(ImageChoiceItem, DataSetShowWidget)
@@ -443,6 +511,7 @@ DataSetShowLayout.register(FloatArrayItem, DataSetShowWidget)
 
 class DataSetShowGroupBox(QGroupBox):
     """Group box widget showing a read-only DataSet"""
+
     def __init__(self, label, klass, wordwrap=False, **kwargs):
         QGroupBox.__init__(self, label)
         self.klass = klass
@@ -456,10 +525,10 @@ class DataSetShowGroupBox(QGroupBox):
         self.layout.addLayout(self.grid_layout)
         self.setLayout(self.layout)
         self.edit = self.get_edit_layout()
-        
+
     def get_edit_layout(self):
         """Return edit layout"""
-        return DataSetShowLayout(self, self.dataset, self.grid_layout) 
+        return DataSetShowLayout(self, self.dataset, self.grid_layout)
 
     def get(self):
         """Update group box contents from data item values"""
@@ -478,14 +547,21 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
     button_text: action button text (default: "Apply")
     button_icon: QIcon object or string (default "apply.png")
     """
-    
+
     #: Signal emitted when Apply button is clicked
     SIG_APPLY_BUTTON_CLICKED = Signal()
-    
-    def __init__(self, label, klass, button_text=None, button_icon=None,
-                 show_button=True, wordwrap=False, **kwargs):
-        DataSetShowGroupBox.__init__(self, label, klass, wordwrap=wordwrap,
-                                     **kwargs)
+
+    def __init__(
+        self,
+        label,
+        klass,
+        button_text=None,
+        button_icon=None,
+        show_button=True,
+        wordwrap=False,
+        **kwargs
+    ):
+        DataSetShowGroupBox.__init__(self, label, klass, wordwrap=wordwrap, **kwargs)
         if show_button:
             if button_text is None:
                 button_text = _("Apply")
@@ -496,13 +572,12 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
             apply_btn = QPushButton(button_icon, button_text, self)
             apply_btn.clicked.connect(self.set)
             layout = self.edit.layout
-            layout.addWidget(apply_btn, layout.rowCount(),
-                             0, 1, -1, Qt.AlignRight)
+            layout.addWidget(apply_btn, layout.rowCount(), 0, 1, -1, Qt.AlignRight)
 
     def get_edit_layout(self):
         """Return edit layout"""
         return DataSetEditLayout(self, self.dataset, self.grid_layout)
-        
+
     def set(self):
         """Update data item values from layout contents"""
         for widget in self.edit.widgets:
@@ -515,4 +590,5 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
         app_name = QApplication.applicationName()
         if not app_name:
             app_name = to_text_string(self.title())
-        return "%s - %s" % ( app_name, item.label() )
+        return "%s - %s" % (app_name, item.label())
+
