@@ -3,9 +3,9 @@
 
 #    userconfig License Agreement (MIT License)
 #    ------------------------------------------
-#    
+#
 #    Copyright © 2009-2012 Pierre Raybaut
-#    
+#
 #    Permission is hereby granted, free of charge, to any person
 #    obtaining a copy of this software and associated documentation
 #    files (the "Software"), to deal in the Software without
@@ -14,10 +14,10 @@
 #    copies of the Software, and to permit persons to whom the
 #    Software is furnished to do so, subject to the following
 #    conditions:
-#    
+#
 #    The above copyright notice and this permission notice shall be
 #    included in all copies or substantial portions of the Software.
-#    
+#
 #    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 #    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 #    OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
@@ -40,15 +40,16 @@ It is the exact copy of the open-source package `userconfig` (MIT license).
 
 from __future__ import print_function
 
-__version__ = '1.0.7'
+__version__ = "1.0.7"
 
 import os
 import re
 import os.path as osp
 import sys
 
-from guidata.py3compat import configparser as cp
-from guidata.py3compat import is_text_string, is_unicode, PY2
+from qtpy.py3compat import configparser as cp
+from qtpy.py3compat import is_text_string, is_unicode, PY2
+
 
 def _check_values(sections):
     # Checks if all key/value pairs are writable
@@ -65,25 +66,28 @@ def _check_values(sections):
         assert False
     else:
         import traceback
-        print("-"*30)
+
+        print("-" * 30)
         traceback.print_stack()
 
+
 def get_home_dir():
     """
     Return user home directory
     """
     try:
-        path = osp.expanduser('~')
+        path = osp.expanduser("~")
     except:
-        path = ''
-    for env_var in ('HOME', 'USERPROFILE', 'TMP'):
+        path = ""
+    for env_var in ("HOME", "USERPROFILE", "TMP"):
         if osp.isdir(path):
             break
-        path = os.environ.get(env_var, '')
+        path = os.environ.get(env_var, "")
     if path:
         return path
     else:
-        raise RuntimeError('Please define environment variable $HOME')
+        raise RuntimeError("Please define environment variable $HOME")
+
 
 def encode_to_utf8(x):
     """Encode unicode string in UTF-8 -- but only with Python 2"""
@@ -91,16 +95,19 @@ def encode_to_utf8(x):
         return x.encode("utf-8")
     else:
         return x
-    
+
+
 def get_config_dir():
     if sys.platform == "win32":
         # TODO: on windows config files usually go in
         return get_home_dir()
     return osp.join(get_home_dir(), ".config")
 
+
 class NoDefault:
     pass
 
+
 class UserConfig(cp.ConfigParser):
     """
     UserConfig class, based on ConfigParser
@@ -111,13 +118,13 @@ class UserConfig(cp.ConfigParser):
     Note that 'get' and 'set' arguments number and type
     differ from the overriden methods
     """
-    
-    default_section_name = 'main'
-    
+
+    default_section_name = "main"
+
     def __init__(self, defaults):
         cp.ConfigParser.__init__(self)
         self.name = "none"
-        self.raw = 0 # 0=substitutions are enabled / 1=raw config parser
+        self.raw = 0  # 0=substitutions are enabled / 1=raw config parser
         assert isinstance(defaults, dict)
         for _key, val in list(defaults.items()):
             assert isinstance(val, dict)
@@ -138,12 +145,14 @@ class UserConfig(cp.ConfigParser):
     def save(self):
         # In any case, the resulting config is saved in config file:
         self.__save()
-    
+
     def set_application(self, name, version, load=True, raw_mode=False):
         self.name = name
         self.raw = 1 if raw_mode else 0
-        if (version is not None) and (re.match('^(\d+).(\d+).(\d+)$', version) is None):
-            raise RuntimeError("Version number %r is incorrect - must be in X.Y.Z format" % version)
+        if (version is not None) and (re.match("^(\d+).(\d+).(\d+)$", version) is None):
+            raise RuntimeError(
+                "Version number %r is incorrect - must be in X.Y.Z format" % version
+            )
 
         if load:
             # If config file already exists, it overrides Default options:
@@ -161,35 +170,37 @@ class UserConfig(cp.ConfigParser):
     def check_default_values(self):
         """Check the static options for forbidden data types"""
         errors = []
+
         def _check(key, value):
             if value is None:
                 return
             if isinstance(value, dict):
                 for k, v in list(value.items()):
-                    _check(key+"{}", k)
-                    _check(key+"/"+k, v)
+                    _check(key + "{}", k)
+                    _check(key + "/" + k, v)
             elif isinstance(value, (list, tuple)):
                 for v in value:
-                    _check(key+"[]", v)
+                    _check(key + "[]", v)
             else:
                 if not isinstance(value, (bool, int, float, str)):
                     errors.append("Invalid value for %s: %r" % (key, value))
+
         for name, section in list(self.defaults.items()):
             assert isinstance(name, str)
             for key, value in list(section.items()):
-                    _check(key, value)
+                _check(key, value)
         if errors:
             for err in errors:
                 print(err)
             raise ValueError("Invalid default values")
 
-    def get_version(self, version='0.0.0'):
+    def get_version(self, version="0.0.0"):
         """Return configuration (not application!) version"""
-        return self.get(self.default_section_name, 'version', version)
-        
-    def set_version(self, version='0.0.0', save=True):
+        return self.get(self.default_section_name, "version", version)
+
+    def set_version(self, version="0.0.0", save=True):
         """Set configuration (not application!) version"""
-        self.set(self.default_section_name, 'version', version, save=save)
+        self.set(self.default_section_name, "version", version, save=save)
 
     def __load(self):
         """
@@ -201,10 +212,10 @@ class UserConfig(cp.ConfigParser):
                 self.read(self.filename())
             else:
                 # Python 3
-                self.read(self.filename(), encoding='utf-8')
+                self.read(self.filename(), encoding="utf-8")
         except cp.MissingSectionHeaderError:
             print("Warning: File contains no section headers.")
-        
+
     def __remove_deprecated_options(self):
         """
         Remove options which are present in the .ini file but not in defaults
@@ -215,7 +226,7 @@ class UserConfig(cp.ConfigParser):
                     self.remove_option(section, option)
                     if len(self.items(section, raw=self.raw)) == 0:
                         self.remove_section(section)
-        
+
     def __save(self):
         """
         Save config into the associated .ini file
@@ -225,19 +236,19 @@ class UserConfig(cp.ConfigParser):
             os.remove(fname)
         if PY2:
             # Python 2
-            with open(fname, 'w') as configfile:
+            with open(fname, "w") as configfile:
                 self.write(configfile)
         else:
             # Python 3
-            with open(fname, 'w', encoding='utf-8') as configfile:
+            with open(fname, "w", encoding="utf-8") as configfile:
                 self.write(configfile)
-                
+
     def filename(self):
         """
         Create a .ini filename located in user home directory
         """
-        return osp.join(get_config_dir(), '.%s.ini' % self.name)
-        
+        return osp.join(get_config_dir(), ".%s.ini" % self.name)
+
     def cleanup(self):
         """
         Remove .ini file associated to config
@@ -261,11 +272,11 @@ class UserConfig(cp.ConfigParser):
         """
         for section, options in list(self.defaults.items()):
             for option in options:
-                value = options[ option ]
+                value = options[option]
                 self.__set(section, option, value, verbose)
         if save:
             self.__save()
-        
+
     def __check_section_option(self, section, option):
         """
         Private method to check section and option types
@@ -287,7 +298,7 @@ class UserConfig(cp.ConfigParser):
         section = self.__check_section_option(section, option)
         options = self.defaults.get(section, {})
         return options.get(option, NoDefault)
-                
+
     def get(self, section, option, default=NoDefault, raw=None, **kwargs):
         """
         Get an option
@@ -305,7 +316,7 @@ class UserConfig(cp.ConfigParser):
                 raise RuntimeError("Unknown section %r" % section)
             else:
                 self.add_section(section)
-        
+
         if not self.has_option(section, option):
             if default is NoDefault:
                 raise RuntimeError("Unknown option %r/%r" % (section, option))
@@ -347,11 +358,11 @@ class UserConfig(cp.ConfigParser):
         Private set method
         """
         if not self.has_section(section):
-            self.add_section( section )
+            self.add_section(section)
         if not is_text_string(value):
-            value = repr( value )
+            value = repr(value)
         if verbose:
-            print('%s[ %s ] = %s' % (section, option, value))
+            print("%s[ %s ] = %s" % (section, option, value))
         cp.ConfigParser.set(self, section, option, encode_to_utf8(value))
 
     def set_default(self, section, option, default_value):
@@ -384,11 +395,11 @@ class UserConfig(cp.ConfigParser):
         self.__set(section, option, value, verbose)
         if save:
             self.__save()
-            
+
     def remove_section(self, section):
         cp.ConfigParser.remove_section(self, section)
         self.__save()
-            
+
     def remove_option(self, section, option):
         cp.ConfigParser.remove_option(self, section, option)
         self.__save()
